#!/usr/bin/env python
#-*- coding: iso-8859-15 -*-

#################################################################################
## Coban - Module de calcul de chute de tension                                ## 
## Copyright (C) 2008  Stphan GURIN                                          ##
## contact : setthe@tuxfamily.org                                              ##
##                                                                             ##
## This program is free software; you can redistribute it and/or               ##
## modify it under the terms of the GNU General Public License                 ##
## as published by the Free Software Foundation; either version 2              ##
## of the License, or (at your option) any later version.                      ##
##                                                                             ##
## This program is distributed in the hope that it will be useful,             ##
## but WITHOUT ANY WARRANTY; without even the implied warranty of              ##
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               ##
## GNU General Public License for more details.                                ##
##                                                                             ##
## You should have received a copy of the GNU General Public License           ##
## along with this program; if not, write to the Free Software                 ##
## Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. ##
#################################################################################

import wx

############################################################################
##                                                                        ##
##                       Module chute de tension                          ##
##                                                                        ##
##                                                                        ##
############################################################################

version = 'Chute de tension 0.2.1'
sectCu = ' 1.5 2.5 4 6 10 16 25  35 50 70 95 120 150 185 240 300 400 500 630'.split()
sectAlu = '25 35 50 70 95 120 150 185 240 300 400 630'.split()
statusText = u"Chute de tension"

      

class ModuleChute(wx.Frame):
    """Calcul des sections de cble"""
    def __init__(self, parent):
        wx.Frame.__init__(self, parent, -1, title = version,
                      style=wx.DEFAULT_FRAME_STYLE 
                      ^(wx.RESIZE_BORDER | wx.MAXIMIZE_BOX))
        self.parent = parent
        
        #------- Cration du panel -----------------------        
        panel =  wx.Panel(self, -1, style = wx.TAB_TRAVERSAL
                     | wx.CLIP_CHILDREN
                     | wx.FULL_REPAINT_ON_RESIZE
                     )
        
        #---------- cration du sizer principal ----------------
        
        self.gbs = wx.GridBagSizer(hgap=5, vgap=5)
        
        #------- Cration de statusbar -----------------        
        self.CreateStatusBar()
        self.SetStatusText(statusText)
        
        #---- Cration de la barre d'outils (toolbar) ---------------------------------------------------

        #-------------- import des images ----------------------
        
        from modcoban import bmp_aide, bmp_quit
        
        img_aide = wx.Bitmap(bmp_aide, wx.BITMAP_TYPE_PNG)
        img_quit = wx.Bitmap(bmp_quit, wx.BITMAP_TYPE_PNG)
        
        self.tbar = wx.ToolBar(self, -1, style= wx.TB_HORIZONTAL)
        # Hack pour windows :
        # ajustement de la taille des boutons aux images (24x24 px):
        self.tbar.SetToolBitmapSize((24,24))
        
        self.tbar.AddSimpleTool(90, 
                                img_aide,
                                shortHelpString = u"Aide",
                                longHelpString = u"Valeurs maxi des chutes de tension")
        self.tbar.AddSeparator()
        self.tbar.AddSimpleTool(99, 
                           img_quit,
                           shortHelpString = "Quitter",
                           longHelpString = "Quitter ce module")
        self.tbar.Realize()
        self.SetToolBar(self.tbar)
        
        
        
        #------------- Cration des widgets ---------------------
        # Mono / Tri
        listeCircuit=[u'monophas', u'triphas']
        labelMonoTri = wx.StaticText(panel, -1, u'Type de circuit')
        self.monoTri = wx.Choice(panel, -1, choices=listeCircuit)
        self.monoTri.SetSelection(1)
        self.monoTri.SetFocus()
        self.labelCosPhi = wx.StaticText(panel, -1, u'cos Phi = 0,8')
        # type de cble :
        listeCable = ['Cuivre', 'Aluminium']
        labelCable = wx.StaticText(panel, -1, u"Type de cble")
        self.cable = wx.Choice(panel, -1, choices=listeCable)
        self.cable.SetSelection(0)
        # Longueur du cble
        labelLg = wx.StaticText(panel, -1, u'Longueur du cble\n(en mtres) :')
        self.lg = wx.SpinCtrl(panel, -1, "", size=self.cable.GetSize())
        self.lg.SetRange(1, 999)
        self.lg.SetValue(100)
        # Section du conducteur
        labelSection = wx.StaticText(panel, -1, u'Section du conducteur\n (en mm)')
        self.section = wx.Choice(panel, -1, choices=sectCu, size=self.cable.GetSize())
        self.section.SetSelection(5)
        # Courant d'emploi
        labelCourant = wx.StaticText(panel, -1, u"Courant d'emploi\n(en Ampres)")
        self.courant = wx.SpinCtrl(panel, -1, "", size=self.cable.GetSize())
        self.courant.SetRange(1,999)
        self.courant.SetValue(100)
        # Tension Ph/N
        labelTension = wx.StaticText(panel, -1, u'Tension entre phase\net neutre (en Volts)')
        listeTension = ['110V', '230V', '240 V', '380 V', '400 V']
        self.tension = wx.Choice(panel, -1, choices=listeTension, size=self.cable.GetSize())
        self.tension.SetSelection(1)
        # Bouton calcul
        self.btnCalc = wx.Button(panel, -1, 'Calculer')
        self.btnCalc.SetBackgroundColour('yellow')
        self.btnCalc.SetDefault()
        # Sparation
        sep = wx.BoxSizer(wx.VERTICAL)
        sep.Add(wx.StaticLine(panel), 0, wx.EXPAND|wx.ALL, 5)
        # Rsultats
        labelResult = wx.StaticText(panel, -1, u'Rsultats')
        labelResult.SetFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
        labelChuteDelta=wx.StaticText(panel, -1, u'Chute de tension\n(en %)')
        self.labelDeltaU = wx.StaticText(panel, -1, u'... %')
        self.labelDeltaU.SetForegroundColour('blue')
        self.labelDeltaU.SetFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
        labelChuteV = wx.StaticText(panel, -1, u'Chute de tension\n(en Volts)')
        self.labelChuteVolt = wx.StaticText(panel, -1, u'... V')
        self.labelChuteVolt.SetForegroundColour('blue')
        self.labelChuteVolt.SetFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
        
        #------------------ binds ------------------------------
        self.Bind(wx.EVT_CHOICE, self.onRaz)
        self.Bind(wx.EVT_SPINCTRL, self.onRaz)
        self.Bind(wx.EVT_BUTTON, self.onCalcul, self.btnCalc)
        self.Bind(wx.EVT_TOOL, self.onAide, id=90)
        self.Bind(wx.EVT_CLOSE, self.onQuitter)
        self.Bind(wx.EVT_TOOL, self.onQuitter, id=99)
        
        #---------------- placement des widgets ------------------
        self.gbs.Add(labelMonoTri, (0,0))
        self.gbs.Add(self.monoTri, (0,1))
        self.gbs.Add(self.labelCosPhi, (0,2))
        self.gbs.Add(labelCable, (1,0))
        self.gbs.Add(self.cable, (1,1))
        self.gbs.Add(labelLg, (2,0))
        self.gbs.Add(self.lg, (2,1))
        self.gbs.Add(labelSection, (3,0))
        self.gbs.Add(self.section, (3,1))
        self.gbs.Add(labelCourant, (4,0))
        self.gbs.Add(self.courant, (4,1))
        self.gbs.Add(labelTension, (5,0))
        self.gbs.Add(self.tension, (5,1))
        self.gbs.Add(self.btnCalc, (6,2))
        self.gbs.Add(sep, (7,0), (1,4),wx.EXPAND)
        self.gbs.Add(labelResult, (8,0))
        self.gbs.Add(labelChuteDelta, (9,0))
        self.gbs.Add(self.labelDeltaU, (9,1))
        self.gbs.Add(labelChuteV, (10,0))
        self.gbs.Add(self.labelChuteVolt, (10,1))
                
        #-------- rglage de la taille ---------------------------
        panel.SetSizerAndFit(self.gbs)
        self.SetClientSize(panel.GetSize())
        
        
        
    def onAide(self, evt):
        msgAide = (u'Alimentation entre disjoncteur de branchement et tableau de rpartition :\n'
                   u'  - Chute de tension maximale : 2%\n\n'
                   u'Installations alimentes directement  partir d\'un rseau de '
                   u'distribution publique basse tension :\n'
                   u'  - clairage : 3 % max\n'
                   u'  - Autres usages : 5 % max\n\n'
                   u'Installations alimentes  partir d\'un poste HT/BT :\n'
                   u'  - clairage : 6 % max\n'
                   u'  - Autres usages : 8 % max'
                   )

        dlg = wx.MessageDialog(self, msgAide,
                               u'Mmo Chute de tension',
                               wx.OK | wx.ICON_INFORMATION
                               #wx.YES_NO | wx.NO_DEFAULT | wx.CANCEL | wx.ICON_INFORMATION
                               )
        dlg.ShowModal()
        dlg.Destroy()
        
    
        
    def onRaz(self, evt):
        self.labelChuteVolt.SetLabel('... V')
        self.labelDeltaU.SetLabel('... %')
        if self.monoTri.GetSelection() == 0:
            self.labelCosPhi.SetLabel(u'')
        else :
            self.labelCosPhi.SetLabel(u'cos Phi = 0,8')
            
        
    def onCalcul(self, evt):
        # import si mono ou tri
        if self.monoTri.GetSelection()==0:
            b = 2
            cosPhi = 1
            sinPhi = 1
        else : 
            b = 1
            cosPhi = 0.8
            sinPhi = 0.6
        # import de la rsistivit
        if self.cable.GetSelection() == 0:
            rau1 = 23
        else :
            rau1 = 37
        # import de la longueur
        L = self.lg.GetValue()
        # import de la section
        S = float(self.section.GetStringSelection())
        # import du courant d'emploi
        Ib = self.courant.GetValue()
        # import de la tension
        if self.tension.GetSelection() == 0:
            Uo = 110
        elif self.tension.GetSelection() == 1:
            Uo = 230
        elif self.tension.GetSelection() == 2:
            Uo = 240
        elif self.tension.GetSelection() == 3:
            Uo = 380
        else :
            Uo = 400
        # coef lambda
        Lambda = 0.08
        
        # rsultats
        u = round((b*(rau1*(L/S)*cosPhi+Lambda*L*sinPhi)*Ib)/1000, 3)
        deltaU = round((100*(u/Uo)), 2)
        self.labelChuteVolt.SetLabel(u'%s V'%u)
        self.labelDeltaU.SetLabel((u'%s '%deltaU)+'%')
    
    def onQuitter(self, evt):
        """Quitter l'application"""
        self.parent.btnChute.Enable(True)
        self.parent.menuModuleChute.Enable(True)
        self.Destroy()