#!/usr/bin/env python
#-*- coding: iso-8859-15 -*-

#################################################################################
## Coban                                                                       ## 
## Copyright (C) 2008  Stphan GURIN                                          ##
## contact : setthe@tuxfamily.org                                              ##
##                                                                             ##
## This program is free software; you can redistribute it and/or               ##
## modify it under the terms of the GNU General Public License                 ##
## as published by the Free Software Foundation; either version 2              ##
## of the License, or (at your option) any later version.                      ##
##                                                                             ##
## This program is distributed in the hope that it will be useful,             ##
## but WITHOUT ANY WARRANTY; without even the implied warranty of              ##
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               ##
## GNU General Public License for more details.                                ##
##                                                                             ##
## You should have received a copy of the GNU General Public License           ##
## along with this program; if not, write to the Free Software                 ##
## Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. ##
#################################################################################


version = "0.8.1"


############################################################################
##                                                                        ##
##           LANCEUR PRINCIPAL DU LOGICIEL COBAN                          ##
##                                                                        ##
############################################################################

try :
    import wx
except :
    print u"Coban ncessite l'installation de wxPython pour fonctionner"
import wx.html
from wx.lib.wordwrap import wordwrap
from modcoban import icone
import os, sys


# ------------ Dmarrage ----------------------#

# cration du texte de la licence
try :
    f = open('licence.txt', 'r')
    licenseText = f.read()
    f.close()
except :
    licenseText = (
        u'Ce logiciel est distribu sous licence GPL.\n'
        u'\nLe fichier "licence.txt" qui contient la licence est manquant !'
        )
    
# teste si le dossier .coban de l'utilisateur existe, sinon le cre
path = os.path.join(os.path.expanduser("~"),'.coban')
if os.path.exists(path) == False:
    os.mkdir(path)

#-----------------------------------------------------------------------------------

def changeDir():
    """ conversion du rpertoire courant en rpertoire de travail """
    path = os.getcwd()
    os.chdir(path)

# Conversion des chemins en fonction de l'OS
def opj(path):
    """Convert paths to the platform-specific separator"""
    st = apply(os.path.join, tuple(path.split('/')))
    # HACK: on Linux, a leading / gets lost...
    if path.startswith('/'):
        st = '/' + st
    return st

#--------------------------------------------------------------------------------------

class Coban(wx.App):
    """Application principale"""
    def OnInit(self):
        # cration de la fentre principale
        frame = Principale("Coban %s" % version)         
        # insertion de l'icone de l'application 
        icone(frame)
        frame.Show(True)
        self.SetTopWindow(frame)
        changeDir()
        return True

#--------------------------------------------------------------------------------------


class Aide(wx.Frame):
    """Aide au format html"""
    def __init__(self, parent, title):
        wx.Frame.__init__(self, parent, -1, title, size=(800,600))
        html = wx.html.HtmlWindow(self)
        if "gtk2" in wx.PlatformInfo:
            html.SetStandardFonts()
            
        html.LoadFile('help.html')
        icone(self)
       
    def onClose(self, event):
        self.Destroy()
        


#--------------------------------------------------------------------------------------


class Principale(wx.Frame):
    """Lanceur principal des diffrents modules"""
    def __init__(self, titre):
        wx.Frame.__init__(self, None, -1, title = titre,
                      style=wx.DEFAULT_FRAME_STYLE 
                      ^(wx.RESIZE_BORDER | wx.MAXIMIZE_BOX))
        
        ############## Cration du panel #########################
        
        panel =  wx.Panel(self, -1, style = wx.TAB_TRAVERSAL
                     | wx.CLIP_CHILDREN
                     | wx.FULL_REPAINT_ON_RESIZE
                     )
        
        ############## cration du sizer principal ###############
        
        self.gbs = wx.GridBagSizer(hgap=5, vgap=5)
        
        ############## Cration de statusbar #####################
        
        self.CreateStatusBar()
        self.SetStatusText("Consultez l'aide pour plus d'infos sur les modules")
        
        ################# CRATION DES MENUS #######################
        
        barreMenu = wx.MenuBar()
        
        # Menu des modules
        self.menuModule = wx.Menu()
        
        # sous-menu "Calculs" ---------------------------------------------------------------------
        self.sousMenuCalcul = wx.Menu()
        # module section
        self.menuModuleSection = self.sousMenuCalcul.Append(wx.ID_ANY, u"Section de cble", 
                                              u"Calcul de section de cble")
        self.Bind(wx.EVT_MENU, self.onSection, self.menuModuleSection)
        # module chute
        self.menuModuleChute = self.sousMenuCalcul.Append(wx.ID_ANY, u"Chutes de tension", 
                                              u"Calcul de chute de tension")
        self.Bind(wx.EVT_MENU, self.onChute, self.menuModuleChute)
        
        self.menuModule.AppendMenu(-1, u"Calculs", self.sousMenuCalcul)
        self.menuModule.AppendSeparator()
        
        # sous-menu "Conversions" ---------------------------------------------------------------------
        self.sousMenuConv = wx.Menu()
        # module conversion
        self.menuModuleConversion = self.sousMenuConv.Append(wx.ID_ANY, u"Conversions W/A/CV/HP", 
                                                 u"Conversions Watts / Ampres / Chevaux / Horse Power")
        self.Bind(wx.EVT_MENU, self.onConversion, self.menuModuleConversion)
        # module AWG
        self.menuModuleConvAwg = self.sousMenuConv.Append(wx.ID_ANY, u"Conversion AWG", 
                                                 u"Conversion de l'AWG vers mm2")
        self.Bind(wx.EVT_MENU, self.onConvAwg, self.menuModuleConvAwg)

        self.menuModule.AppendMenu(-1, u"Conversions", self.sousMenuConv)
        self.menuModule.AppendSeparator()
        
        # sous-menu "Sono-Vido" ---------------------------------------------------------------------------
        self.sousMenuSonoVideo = wx.Menu()
        # module Vido
        self.menuModuleVideo = self.sousMenuSonoVideo.Append(wx.ID_ANY, u"Calculs de champs de vision",
                                                      u"Calculs de champs de vision en fonction de focales et de distances")
        self.Bind(wx.EVT_MENU, self.onVideo, self.menuModuleVideo)
        # module sono
        self.menuModuleSono = self.sousMenuSonoVideo.Append(wx.ID_ANY, u"HP et puissances",
                                                      u"Calculs du nombre de HP et de la puissance ncessaire")
        self.Bind(wx.EVT_MENU, self.onSono, self.menuModuleSono)
        
        self.menuModule.AppendMenu(-1, u"Sono / Vido", self.sousMenuSonoVideo)
        self.menuModule.AppendSeparator()
        
        # sous-menu "Climatic" -------------------------------------------------------------------------------------
        self.sousMenuClimatic = wx.Menu()
        # module chauffage
        self.menuModuleChauffage = self.sousMenuClimatic.Append(wx.ID_ANY, u'Calculs de puissances calorifiques',
                                                          u'Calculer la puissance ncessaire pour chauffer une pice')
        self.Bind(wx.EVT_MENU, self.onChauffage, self.menuModuleChauffage)
        
        self.menuModule.AppendMenu(-1, u"Climatic", self.sousMenuClimatic)
        self.menuModule.AppendSeparator()
        
        # sous-menu "clairage" ------------------------------------------------------------------------------------
        self.sousMenuEclairage = wx.Menu()
        # module clairage
        self.menuModuleEcl = self.sousMenuEclairage.Append(wx.ID_ANY, u"clairage intrieur",
                                                           u"Calculer de nombre d'appareils d'clairage ncessaires\n"
                                                           u"en fonction du niveau d'clairement souhait")
        self.Bind(wx.EVT_MENU, self.onEclairage, self.menuModuleEcl)
        
        self.menuModule.AppendMenu(-1, u"clairage", self.sousMenuEclairage)
        self.menuModule.AppendSeparator()
        
        # menu quitter ----------------------------------------------------------------------------------------------
        self.menuModuleQuitter = self.menuModule.Append(wx.ID_EXIT, "Quitter", "Quitter l'application...")
        self.Bind(wx.EVT_MENU, self.onQuitter, self.menuModuleQuitter)
        
        # Menu Aide --------------------------------------------------------------------------------------------
        menuAide = wx.Menu()
        menuAideAide = menuAide.Append(wx.ID_HELP,'Aide', u"Aide sur le logiciel")
        self.Bind(wx.EVT_MENU, self.onAide, menuAideAide)
        menuAideApropos = menuAide.Append(wx.ID_ABOUT,'A propos...', u"A propos de ce logiciel...")
        self.Bind(wx.EVT_MENU, self.onApropos, menuAideApropos)
                
        barreMenu.Append(self.menuModule, u"&Modules") 
        barreMenu.Append(menuAide, "&Aide")
        
        self.SetMenuBar(barreMenu)
        
      
        #--------------------- Cration des widgets ----------------------------------
        # Taille des boutons
        colSize = (200,-1)
        
        # titres 
        font = wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD)
        titreConversion = wx.StaticText(panel, -1, u'CONVERSIONS', size=colSize, style=wx.ALIGN_CENTRE)
        titreConversion.SetFont(font)
        titreCalcul = wx.StaticText(panel, -1, u"CALCULS", size=colSize, style=wx.ALIGN_CENTRE)
        titreCalcul.SetFont(font)
        titreSonoVideo = wx.StaticText(panel, -1, u"SONO - VIDO",size=colSize, style=wx.ALIGN_CENTER)
        titreSonoVideo.SetFont(font)
        titreClimatic = wx.StaticText(panel, -1, u"CLIMATIC",size=colSize, style=wx.ALIGN_CENTRE)
        titreClimatic.SetFont(font)
        titreEclairage = wx.StaticText(panel, -1, u"CLAIRAGE",size=colSize, style=wx.ALIGN_CENTRE)
        titreEclairage.SetFont(font)
        
        # bouton section de cble
        self.btnSection = wx.Button(panel, -1, u"Section de cble", size=colSize)
        self.btnSection.SetToolTipString(u"calcul de section de cble")
        self.Bind(wx.EVT_BUTTON, self.onSection, self.btnSection)
        
        # bouton chute de tension
        self.btnChute = wx.Button(panel, -1, u"Chute de tension", size=colSize)
        self.btnChute.SetToolTipString(u"calcul de chutes de tension")
        self.Bind(wx.EVT_BUTTON, self.onChute, self.btnChute)
        
        # bouton Conversions
        self.btnConv = wx.Button(panel, -1, "Conversions", size=colSize)
        self.btnConv.SetToolTipString(u"Convertir Watts en Ampres, CV et HP...")
        self.Bind(wx.EVT_BUTTON, self.onConversion, self.btnConv)
        
        # bouton Conversion AWG
        self.btnConvAwg = wx.Button(panel, -1, "Conversion AWG", size=colSize)
        self.btnConvAwg.SetToolTipString("Convertir des AWG en mm")
        self.Bind(wx.EVT_BUTTON, self.onConvAwg, self.btnConvAwg)
        
        # bouton Vido
        self.btnVideo = wx.Button(panel, -1, "Champs de vision", size=colSize)
        self.btnVideo.SetToolTipString(u"Calculs de champs de vision en fonction de focales et de distances")
        self.Bind(wx.EVT_BUTTON, self.onVideo, self.btnVideo)
        
        # bouton Sono
        self.btnSono = wx.Button(panel, -1, "Sonorisation", size=colSize)
        self.btnSono.SetToolTipString(u"Calculs du nombre de HP et de la puissance ncessaire")
        self.Bind(wx.EVT_BUTTON, self.onSono, self.btnSono)
        
        # bouton chauffage
        self.btnChauff = wx.Button(panel, -1, "Puissances calorifiques", size=colSize)
        self.btnChauff.SetToolTipString(u"Calculs de puissances calorifiques d'une pice")
        self.Bind(wx.EVT_BUTTON, self.onChauffage, self.btnChauff)
        
        # bouton Eclairage
        self.btnEcl = wx.Button(panel, -1, u"clairage intrieur", size=colSize)
        self.btnEcl.SetToolTipString(
            u"Estimer le nombre d'appareils d'clairage ncessaires\n"
            u"en fonction du niveau d'clairement souhait")
        self.Bind(wx.EVT_BUTTON, self.onEclairage, self.btnEcl)
        
        self.Bind(wx.EVT_CLOSE, self.onQuitter)
        
        ############### Ajout des wigets au sizer ####################
        
        self.gbs.Add(titreCalcul, (0,0))
        self.gbs.Add(self.btnSection, (1,0))
        self.gbs.Add(self.btnChute, (2,0))
        
        self.gbs.Add(titreConversion, (0,1))
        self.gbs.Add(self.btnConv, (1,1))
        self.gbs.Add(self.btnConvAwg, (2,1))
        
        self.gbs.Add(titreSonoVideo, (0,2))
        self.gbs.Add(self.btnVideo, (1,2))
        self.gbs.Add(self.btnSono, (2,2))
        
        self.gbs.Add(titreClimatic, (4,0))
        self.gbs.Add(self.btnChauff, (5,0))
        
        self.gbs.Add(titreEclairage, (4,1))
        self.gbs.Add(self.btnEcl, (5,1))
                
        panel.SetSizerAndFit(self.gbs)
        self.SetClientSize(panel.GetSize())
        
        self.Centre() # centre la fentre  l'ouverture sur l'cran
        
    def onSection(self, evt):
        import section
        section.Section(self)
        #self.dlg = section.Section(self)
        #self.btnSection.Enable(False)
        #self.menuModuleSection.Enable(False)
        #icone(self.dlg)
        #self.dlg.Show(True)

    def onChute(self, evt):
        import chute
        self.dlg = chute.ModuleChute(self)
        self.btnChute.Enable(False)
        self.menuModuleChute.Enable(False)
        icone(self.dlg)
        self.dlg.Show(True)
        

    def onConversion(self, evt):
        import conversion
        self.dlg = conversion.ModuleConv(self)
        self.btnConv.Enable(False)
        self.menuModuleConversion.Enable(False)
        icone(self.dlg)
        self.dlg.Show(True)
        
    def onConvAwg(self, evt):
        import convawg
        self.dlg = convawg.Awg(self)
        self.btnConvAwg.Enable(False)
        self.menuModuleConvAwg.Enable(False)
        icone(self.dlg)
        self.dlg.Show(True)
        
    def onVideo(self, evt):
        import video
        self.dlg = video.Video(self)
        self.btnVideo.Enable(False)
        self.menuModuleVideo.Enable(False)
        icone(self.dlg)
        self.dlg.Show(True)
        
    def onSono(self, evt):
        import sono
        self.dlg = sono.Sono(self)
        self.btnSono.Enable(False)
        self.menuModuleSono.Enable(False)
        icone(self.dlg)
        self.dlg.Show(True)
        
    def onChauffage(self, evt):
        import chauffage
        self.dlg = chauffage.Chauffage(self)
        self.btnChauff.Enable(False)
        self.menuModuleChauffage.Enable(False)
        icone(self.dlg)
        self.dlg.Show(True)
        
    def onEclairage(self,evt):
        import eclairage
        self.dlg = eclairage.Eclairage(self)
        self.btnEcl.Enable(False)
        self.menuModuleEcl.Enable(False)
        icone(self.dlg)
        self.dlg.Show(True)
        pass

    def onQuitter(self, evt):
        """Quitter l'application"""
        self.Destroy()

    def onAide(self, evt):
        self.dlg = Aide(self, "Aide" )
        self.dlg.Show(True)
    
    def onApropos(self, evt):
        info = wx.AboutDialogInfo()
        info.Name = "Coban" 
        info.Version = "%s" % version
        info.Description = wordwrap(
            u"Coban est un utilitaire permettant de calculer rapidement la section d'un cble, "
            u"de raliser des conversions d'units lectriques, etc..."
            u"\n\nCe programme est un logiciel libre ; \nVous pouvez le redistribuer et/ou le modifier "
            u"au titre des clauses de la Licence Publique Gnrale GNU"
            u"; \nsoit la version 2 de la Licence, ou "
            u"une version ultrieure quelconque. \n\nCe programme est distribu dans l'espoir qu'il sera "
            u"utile, mais SANS AUCUNE GARANTIE ; \nSans mme une garantie implicite de COMMERCIABILITE ou "
            u"DE CONFORMITE A UNE UTILISATION PARTICULIERE. \nVoir la Licence Publique Gnrale GNU pour "
            u"plus de dtails \n(fichier \"licence.txt\")"
            u"\n\nPour tout contact, visiter le site ci-dessous",
            350, wx.ClientDC(self))
        info.WebSite = ("http://www.coban.tuxfamily.org")
        info.Developers = [ u"Stphan GURIN | setthe@tuxfamily.org"]
        info.Licence = licenseText
        wx.AboutBox(info)    

if __name__ == "__main__":
    app = Coban()
    app.MainLoop()
