#!/usr/bin/env python
#-*- coding: iso-8859-15 -*-

#################################################################################
## Coban - Module de calcul de section de cble                                ## 
## Copyright (C) 2008  Stphan GURIN                                          ##
## contact : setthe@tuxfamily.org                                              ##
##                                                                             ##
## This program is free software; you can redistribute it and/or               ##
## modify it under the terms of the GNU General Public License                 ##
## as published by the Free Software Foundation; either version 2              ##
## of the License, or (at your option) any later version.                      ##
##                                                                             ##
## This program is distributed in the hope that it will be useful,             ##
## but WITHOUT ANY WARRANTY; without even the implied warranty of              ##
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               ##
## GNU General Public License for more details.                                ##
##                                                                             ##
## You should have received a copy of the GNU General Public License           ##
## along with this program; if not, write to the Free Software                 ##
## Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. ##
#################################################################################

import wx
import  wx.wizard
from math import pow

version = u'Section de cble 0.1.4'

############################################################################
##                                                                        ##
##                       Module de calcul de section de cble             ##
##                                                                        ##
##                                                                        ##
##                                                                        ##
############################################################################

sectCu = ' 1.5 2.5 4 6 10 16 25  35 50 70 95 120 150 185 240 300 400 500 630'.split()
sectAlu = '10 16 25 35 50 70 95 120 150 185 240 300 400 500 630'.split()

def calcSect(section, calibre, f0, coef1, exposant1, coef2, exposant2):
    """ 
    Calcule la section adapte au calibre du disjoncteur
    --> Paramtres :
    section = sectCu ou sectAlu 
    calibre = calibre du disjoncteur
    f0 = coef appliqu  la mthode (tableau BD et BE NFC 15-105)
    coef1 = coef du tableau A5 ou A6 NFC 15-500 pour une section =< 16mm
    exposant1 = exposant du tableau A6 NFC 15-500 pour une section =< 16mm
    coef2 = coef du tableau A5 ou A6 NFC 15-500 pour une section >= 25mm
    exposant2 = exposant du tableau A6 NFC 15-500 pour une section >= 25mm
    --> retourne une liste [section, Imax]
    """
    
    for sect in section :
        if float(sect) <= 16 :
            I = int((coef1*pow(float(sect), exposant1))*f0)
            if I >= calibre :
                break
        else :
            I = int((coef2*pow(float(sect), exposant2))*f0)
            if I >= calibre :
                break
            
    return [sect, I]

        
class TitledPage(wx.wizard.WizardPageSimple):
    def __init__(self, parent, title):
        wx.wizard.WizardPageSimple.__init__(self, parent)
        self.sizer = wx.BoxSizer(wx.VERTICAL)
        self.SetSizer(self.sizer)
        titleText = wx.StaticText(self, -1, title)
        titleText.SetFont(
                 wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
        self.sizer.Add(titleText, 0,
                wx.ALIGN_CENTRE | wx.ALL, 5)
        self.sizer.Add(wx.StaticLine(self, -1), 0,
                wx.EXPAND | wx.ALL, 5)

        
class Section(wx.wizard.Wizard):
    def __init__(self, parent):
        wx.wizard.Wizard.__init__(self, parent, -1, title=version)
        self.parent = parent

        #-------------- Cration des pages ------------------------
        self.page1 = TitledPage(self, u"Donnes")
        self.page2 = TitledPage(self, u"Mode de pose")
        self.page3 = TitledPage(self, u"Rsultat Rapide")

        
        #-------------- Polices -----------------------------------
        
        fontTitre = wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD)
        fontMemo = wx.Font(8, wx.SWISS, wx.NORMAL,wx.NORMAL)
        fontResult = wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD)
        fontResult2 = wx.Font(12, wx.SWISS, wx.NORMAL, wx.NORMAL)
        
        #-------------- Page 1 ------------------------------------

        # Choix du calibre du disjoncteur
        lblDisj = wx.StaticText(self.page1, -1, u'Calibre du disjoncteur (en Ampres)')
        lblDisj.SetFont(fontTitre)
        self.disj = wx.SpinCtrl(self.page1, -1, '')
        self.disj.SetRange(1,630)
        self.disj.SetValue(125)
        # Choix du type de circuit (mono ou tri)
        lblCircuit = wx.StaticText(self.page1, -1, u'Type de circuit')
        lblCircuit.SetFont(fontTitre)
        lstCircuit = [u'Monophas',
                      u'Triphas']
        self.circuit = wx.Choice(self.page1, -1, choices=lstCircuit)
        self.circuit.SetSelection(1)
        #Choix du type de cble
        lblConducteur = wx.StaticText(self.page1, -1, u"Type de cble :")
        lblConducteur.SetFont(fontTitre)
        lstConducteur = [u'Cble U-1000 R2V multiconducteur',
                         u'Cble U-1000 R2V monoconducteur',
                         u'Cble AR2V multiconducteur',
                         u'Cble AR2V monoconducteur',
                         u'Cble H-07 RNF multiconducteur',
                         u'Cble H-07 RNF monoconducteur',
                         u'Fil H-07 V-U, V-R ou V-K',
                      ]
        self.conducteur = wx.Choice(self.page1, -1, choices=lstConducteur)
        self.conducteur.SetSelection(0)
        # Aide
        sep1 = wx.StaticText(self.page1, -1, u'')
        lblAide = wx.StaticText(self.page1, -1, 
                              u"Aide :\n"
                              u"U-1000 R2V : Cble rigide conducteur Cuivre\n"
                              u"AR2V : Cble rigide conducteur Aluminium\n"
                              u"H07 RNF : Cble souple conducteur Cuivre\n"
                              u"Fil : fil souple ou rigide simple isolation\n")
        lblAide.SetFont(fontMemo)
        
        
        self.page1.sizer.Add(lblDisj)
        self.page1.sizer.Add(self.disj)
        self.page1.sizer.Add(lblCircuit)
        self.page1.sizer.Add(self.circuit)
        self.page1.sizer.Add(lblConducteur)
        self.page1.sizer.Add(self.conducteur)
        self.page1.sizer.Add(sep1)
        self.page1.sizer.Add(lblAide)

        #-------------- Page 2 -----------------------------------
        
        # rsum des choix de la page 1
        lblresum = wx.StaticText(self.page2, -1, u'Rsum :')
        sep1 = wx.StaticText(self.page2, -1, u'')
        self.resCalibre = wx.StaticText(self.page2, -1, u'')
        self.resCalibre.SetFont(fontMemo)
        self.ResCircuit = wx.StaticText(self.page2, -1 ,u'')
        self.ResCircuit.SetFont(fontMemo)
        self.resCable = wx.StaticText(self.page2, -1, u'')
        self.resCable.SetFont(fontMemo)
        sep2 = wx.StaticText(self.page2, -1, u'')
        
        # Choix du mode de pose
        lblPose = wx.StaticText(self.page2, -1, u'Mode de pose :')
        lblPose.SetFont(fontTitre)
        self.lstModeDePose=[]
        self.Pose = wx.Choice(self.page2, -1, choices=[], size=(400,-1))
        
        self.page2.sizer.Add(lblresum)
        self.page2.sizer.Add(sep1)
        self.page2.sizer.Add(self.resCalibre)
        self.page2.sizer.Add(self.ResCircuit)
        self.page2.sizer.Add(self.resCable)
        self.page2.sizer.Add(sep2)
        self.page2.sizer.Add(lblPose)
        self.page2.sizer.Add(self.Pose)
        
        
        #-------------- Page 3 ------------------------------------
        # Rsultat sans les facteurs de correction
        lblSection = wx.StaticText(self.page3, -1, u'Section calcule :')
        lblSection.SetFont(fontTitre)
        self.section = wx.StaticText(self.page3, -1, u'')
        self.section.SetFont(fontResult)
        self.section.SetForegroundColour('blue')
        self.Imax = wx.StaticText(self.page3, -1, '')
        self.Imax.SetFont(fontResult2)
        
        # rsum des choix de la page 1 et 2
        lblresum = wx.StaticText(self.page3, -1, u'Rsum :')
        self.resCalibre2 = wx.StaticText(self.page3, -1, u'')
        self.resCalibre2.SetFont(fontMemo)
        self.ResCircuit2 = wx.StaticText(self.page3, -1 ,u'')
        self.ResCircuit2.SetFont(fontMemo)
        self.resCable2 = wx.StaticText(self.page3, -1, u'')
        self.resCable2.SetFont(fontMemo)
        self.resModePose = wx.StaticText(self.page3, -1, u'')
        self.resModePose.SetFont(fontMemo)
        
        sep1 = wx.StaticText(self.page3, -1, u'')
        sep2 = wx.StaticText(self.page3, -1, u'')
        sep3 = wx.StaticText(self.page3, -1, u'')
        
        self.page3.sizer.Add(lblresum)
        self.page3.sizer.Add(sep1)
        self.page3.sizer.Add(self.resCalibre2)
        self.page3.sizer.Add(self.ResCircuit2)
        self.page3.sizer.Add(self.resCable2)
        self.page3.sizer.Add(self.resModePose)
        self.page3.sizer.Add(sep2)
        self.page3.sizer.Add(lblSection)
        self.page3.sizer.Add(self.section)
        self.page3.sizer.Add(sep3)
        self.page3.sizer.Add(self.Imax)
        

        
        #-------------- Chainage des pages -------------------------
        
        wx.wizard.WizardPageSimple_Chain(self.page1, self.page2)
        wx.wizard.WizardPageSimple_Chain(self.page2, self.page3)
        
        #-------------- Taille du wizard --------------------------
        
        self.FitToPage(self.page1)
        
        #-------------- Binds ------------------------------------
        
        self.Bind(wx.wizard.EVT_WIZARD_PAGE_CHANGING, self.OnWizPageChanging)
        self.Bind(wx.wizard.EVT_WIZARD_PAGE_CHANGED, self.OnWizPageChanged)
        self.Bind(wx.EVT_CLOSE, self.onQuitter)
        
        #-------------- Fin du Wizard -------------------------------
        
        if self.RunWizard(self.page1):
            # si le wizard finit correctement
            wx.MessageBox(u"Pensez  vrifier la CHUTE DE TENSION  l'extrmit du cble\n"
                          u"(Consultez l'aide pour plus d'informations)", 
                          u"ATTENTION !!!!!",
                          wx.ICON_EXCLAMATION)
            self.Destroy()
        else :
            # si le wizard ne va pas jusqu'au bout
            self.Destroy()
            
    def OnWizPageChanged(self, evt):
        texts= (('< &Back','< &Retour'),('&Next >','&Suivant >'),('&Cancel','&Annuler'),('&Finish','Fin'))
        for o in self.GetChildren():
            if 'Button' in str(type(o)):
                for tEng,tFr in texts:
                    if o.GetLabel() == tEng:
                        o.SetLabel(tFr)
        if evt.GetDirection():
            dir = "forward"
        else:
            dir = "backward"
            
    def OnWizPageChanging(self, evt):
        
        #-------------------------- rcupration de la page -------------------------------------------
        
        page = evt.GetPage()       
        
        #-------------------------- Appui sur le bouton "NEXT" PAGE 1 ---------------------------------
        
        if evt.GetDirection(): 
            
            #============ Appui sur le bouton "NEXT" PAGE 1  ===================
            # Cre la page 2 en fonction du type de cble
        
            if page is self.page1 :  
                # rsum de la page 1
                self.resCable.SetLabel("Conducteur : %s"%self.conducteur.GetStringSelection())
                self.resCalibre.SetLabel("Calibre : %s A"%self.disj.GetValue())
                self.ResCircuit.SetLabel("Circuit : %s"%self.circuit.GetStringSelection())
                # si le conducteur est un fil
                if self.conducteur.GetSelection() == 6:
                    self.lstModeDePose = [u'Sous conduit encastr dans des parois thermiquement isolantes',
                                          u'Sous conduit en montage apparent',
                                          u'Sous conduit encastr dans des parois'
                                          ]
                    self.Pose.SetItems(self.lstModeDePose)
                    self.Pose.SetSelection(0)
                    
                    self.cond = "fil"
                    self.isolant = "PVC"
                    self.ame = "cuivre"
                    
                #sinon le conducteur est un cble
                else :
                    self.lstModeDePose = [u'Sous conduit encastr dans des parois thermiquement isolantes',
                                          u'Sous conduit en montage apparent',
                                          u'Sous conduit encastr dans des parois',
                                          u'Sur chemin de cble perfor',
                                          u'Sur chemin de cble filaire',
                                          u'Enterr sous fourreau ou conduit',
                                          u'Enterr',
                                          u'Suspendu'
                                          ]
                    self.Pose.SetItems(self.lstModeDePose)
                    self.Pose.SetSelection(1)
                    
                    self.cond = "cable"
                    
                    # si RO2V multi
                    if self.conducteur.GetSelection() == 0 :
                        self.typeCond = "multi"
                        self.isolant = "PR"
                        self.ame = "cuivre"
                        
                    # si R02V mono
                    elif self.conducteur.GetSelection() == 1 : 
                        self.typeCond = "mono"
                        self.isolant = "PR"
                        self.ame = "cuivre"
                        
                    # si AR2V multi
                    elif self.conducteur.GetSelection() == 2 :
                        self.typeCond = "multi"
                        self.isolant = "PR"
                        self.ame = "alu"
                        
                    # si AR2V mono
                    elif self.conducteur.GetSelection() == 3 :
                        self.typeCond = "mono"
                        self.isolant = "PR"
                        self.ame = "alu"
                        
                    # si H07RNF multi
                    elif self.conducteur.GetSelection() == 4 :
                        self.typeCond = "multi"
                        self.isolant = "PVC"
                        self.ame = "cuivre"
                        
                    # si H07RNF mono
                    else :
                        self.typeCond = "mono"
                        self.isolant = "PVC"
                        self.ame = "cuivre"
                        
                        
                        
                        
                    
            #=========== Appui sur le bouton "NEXT" PAGE 2 =======================
            # Cre la page 3 en fonction du mode de pose

            if page is self.page2 :
                
                # rsum de la page 1 et 2               
                self.resCable2.SetLabel("Conducteur : %s"%self.conducteur.GetStringSelection())
                self.resCalibre2.SetLabel("Calibre : %s A"%self.disj.GetValue())
                self.ResCircuit2.SetLabel("Circuit : %s"%self.circuit.GetStringSelection())
                self.resModePose.SetLabel("Pose : %s"%self.Pose.GetStringSelection())
                
                # teste si le conducteur est un cble ou un fil                
                # si conducteur est un cable
                if self.cond == "cable" :                  
                    # teste si le cble est mono ou multiconducteur
                    
                    # si cable monoconducteur :
                    if self.typeCond == "mono" :
                        
                        # si le conducteur est suspendu
                        if self.Pose.GetSelection() == 7 :
                            self.methode = "F"
                            self.f0 = 1
                            self.f1 = "BF1"
                   
                        # si le conducteur est enterr
                        if self.Pose.GetSelection() == 6 :
                            self.methode = "D"
                            self.f0 = 1
                            self.f1 = "BF2"
                        
                        # si le cond est enterr sous conduit
                        if self.Pose.GetSelection() == 5 :
                            self.methode = "D"
                            self.f0 = 0.8
                            self.f1 = "BF2"
        
                        # Sur chemin de cble filaire
                        if self.Pose.GetSelection() == 4 :
                            self.methode = "F"
                            self.f0 = 1
                            self.f1 = "BF1"
                            
                        # Sur chemin de cble perfor
                        if self.Pose.GetSelection() == 3 :
                            self.methode = "F"
                            self.f0 = 1
                            self.f1 = "BF1"
                        
                        # Sous conduit encastr dans des parois
                        if self.Pose.GetSelection() == 2 :
                            self.methode = "B"
                            self.f0 = 0.9
                            self.f1 = "BF1"
                        
                        # Sous conduit en montage apparent
                        if self.Pose.GetSelection() == 1 :
                            self.methode = "B"
                            self.f0 = 0.9
                            self.f1 = "BF1"
                            
                        # Sous conduit encastr dans des parois thermiquement isolantes
                        if self.Pose.GetSelection() == 0 :
                            self.methode = "B"
                            self.f0 = 0.7
                            self.f1 = "BF1"
                            
                    # si cable multiconducteur :
                    else :
                        # si le conducteur est suspendu
                        if self.Pose.GetSelection() == 7 :
                            self.methode = "E"
                            self.f0 = 1
                            self.f1 = "BF1"
                   
                        # si le conducteur est enterr
                        if self.Pose.GetSelection() == 6 :
                            self.methode = "D"
                            self.f0 = 1
                            self.f1 = "BF2"
                        
                        # si le cond est enterr sous conduit
                        if self.Pose.GetSelection() == 5 :
                            self.methode = "D"
                            self.f0 = 0.8
                            self.f1 = "BF2"
        
                        # Sur chemin de cble filaire
                        if self.Pose.GetSelection() == 4 :
                            self.methode = "E"
                            self.f0 = 1
                            self.f1 = "BF1"
                            
                        # Sur chemin de cble perfor
                        if self.Pose.GetSelection() == 3 :
                            self.methode = "E"
                            self.f0 = 1
                            self.f1 = "BF1"
                        
                        # Sous conduit encastr dans des parois
                        if self.Pose.GetSelection() == 2 :
                            self.methode = "B"
                            self.f0 = 0.9
                            self.f1 = "BF1"
                        
                        # Sous conduit en montage apparent
                        if self.Pose.GetSelection() == 1 :
                            self.methode = "B"
                            self.f0 = 0.9
                            self.f1 = "BF1"
                            
                        # Sous conduit encastr dans des parois thermiquement isolantes
                        if self.Pose.GetSelection() == 0 :
                            self.methode = "B"
                            self.f0 = 0.7
                            self.f1 = "BF1"
                            
                            
                        
                # sinon le conducteur est un fil
                else :
                    # Sous conduit encastr dans des parois
                    if self.Pose.GetSelection() == 2 :
                        self.methode = "B"
                        self.f0 = 1
                        self.f1 = "BF1"
                    
                    # Sous conduit en montage apparent
                    if self.Pose.GetSelection() == 1 :
                        self.methode = "B"
                        self.f0 = 1
                        self.f1 = "BF1"
                    
                    # Sous conduit encastr dans des parois thermiquement isolantes
                    if self.Pose.GetSelection() == 0 :
                        self.methode = "B"
                        self.f0 = 0.77
                        self.f1 = "BF1"                
                
                # rcupration du calibre du disjoncteur et calcul de l'intensit avec le coef f0
                cal = self.disj.GetValue()
                phase = self.circuit.GetSelection()

                
                # si mthode D --------------------------------------------------------------------
                if self.methode == "D":
                    # si monophas
                    if phase == 0 :
                        # si PVC (forcmnt cuivre)
                        if self.isolant == "PVC" :
                            result = calcSect(sectCu, cal, self.f0, 25.14, 0.551, 25.14, 0.551)
                            self.section.SetLabel(u'%s mm'%result[0])
                            self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                            
                        # si PR
                        else :
                            # si cuivre
                            if self.ame == "cuivre" :
                                result = calcSect(sectCu, cal, self.f0, 29.71, 0.548, 29.71, 0.548)
                                self.section.SetLabel(u'%s mm'%result[0])
                                self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                            # si alu
                            if self.ame == "alu" :
                                result = calcSect(sectAlu, cal, self.f0, 22.57, 0.550, 22.57, 0.550)
                                self.section.SetLabel(u'%s mm'%result[0])
                                self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                    # si triphas :
                    else :
                        # si PVC (forcmnt cuivre)
                        if self.isolant == "PVC" :
                            result = calcSect(sectCu, cal, self.f0, 20.86, 0.550, 20.86, 0.550)
                            self.section.SetLabel(u'%s mm'%result[0])
                            self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                            
                        # si PR
                        else :
                            # si cuivre
                            if self.ame == "cuivre" :
                                result = calcSect(sectCu, cal, self.f0, 24.71, 0.549, 24.71, 0.549)
                                self.section.SetLabel(u'%s mm'%result[0])
                                self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                            # si alu
                            if self.ame == "alu" :
                                result = calcSect(sectAlu, cal, self.f0, 19., 0.551, 19., 0.551)
                                self.section.SetLabel(u'%s mm'%result[0])
                                self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                
                # si mthode B --------------------------------------------------------
                if self.methode == "B":
                    # si monophas
                    if phase == 0 :
                        # si PVC 
                        if self.isolant == "PVC" :
                            # forcment cuivre
                                result = calcSect(sectCu, cal, self.f0, 13.5, 0.625, 12.4, 0.635)
                                self.section.SetLabel(u'%s mm'%result[0])
                                self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                            
                        # si PR
                        else :
                            # si cuivre
                            if self.ame == "cuivre" :
                                result = calcSect(sectCu, cal, self.f0, 17.8, 0.623, 16.4, 0.637)
                                self.section.SetLabel(u'%s mm'%result[0])
                                self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                            # si alu
                            if self.ame == "alu" :
                                result = calcSect(sectAlu, cal, self.f0, 13,7, 0.623, 12.6, 0.635)
                                self.section.SetLabel(u'%s mm'%result[0])
                                self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                    # si triphas :
                    else :
                        # si PVC (forcmnt cuivre)
                        if self.isolant == "PVC" :
                            result = calcSect(sectCu, cal, self.f0, 11.84, 0.628, 11.84, 0.628)
                            self.section.SetLabel(u'%s mm'%result[0])
                            self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                            
                        # si PR
                        else :
                            # si cuivre
                            if self.ame == "cuivre" :
                                result = calcSect(sectCu, cal, self.f0, 15.0, 0.625, 15.0, 0.625)
                                self.section.SetLabel(u'%s mm'%result[0])
                                self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                            # si alu
                            if self.ame == "alu" :
                                result = calcSect(sectAlu, cal, self.f0, 11.6, 0.625, 10.55, 0.640)
                                self.section.SetLabel(u'%s mm'%result[0])
                                self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                                
                # si mthode C --------------------------------------------------------
                if self.methode == "C":
                    # si monophas
                    if phase == 0 :
                        # si PVC 
                        if self.isolant == "PVC" :
                            # forcment cuivre
                                result = calcSect(sectCu, cal, self.f0, 15.0, 0.625, 15.0, 0.625)
                                self.section.SetLabel(u'%s mm'%result[0])
                                self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                            
                        # si PR
                        else :
                            # si cuivre
                            if self.ame == "cuivre" :
                                result = calcSect(sectCu, cal, self.f0, 18.77, 0.628, 17.0, 0.650)
                                self.section.SetLabel(u'%s mm'%result[0])
                                self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                            # si alu
                            if self.ame == "alu" :
                                result = calcSect(sectAlu, cal, self.f0, 14.8, 0.625, 12.6, 0.648)
                                self.section.SetLabel(u'%s mm'%result[0])
                                self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                    # si triphas :
                    else :
                        # si PVC (forcmnt cuivre)
                        if self.isolant == "PVC" :
                            result = calcSect(sectCu, cal, self.f0, 13.5, 0.625, 12.4, 0.635)
                            self.section.SetLabel(u'%s mm'%result[0])
                            self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                            
                        # si PR
                        else :
                            # si cuivre
                            if self.ame == "cuivre" :
                                result = calcSect(sectCu, cal, self.f0, 16.8, 0.620, 15.4, 0.635)
                                self.section.SetLabel(u'%s mm'%result[0])
                                self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                            # si alu
                            if self.ame == "alu" :
                                result = calcSect(sectAlu, cal, self.f0, 12.8, 0.627, 11.5, 0.639)
                                self.section.SetLabel(u'%s mm'%result[0])
                                self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                
                                
                                
                                
                # si mthode E --------------------------------------------------------
                if self.methode == "E":
                    # si monophas
                    if phase == 0 :
                        # si PVC 
                        if self.isolant == "PVC" :
                            # forcment cuivre
                                result = calcSect(sectCu, cal, self.f0, 16.8, 0.620, 15.4, 0.635)
                                self.section.SetLabel(u'%s mm'%result[0])
                                self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                            
                        # si PR
                        else :
                            # si cuivre
                            if self.ame == "cuivre" :
                                result = calcSect(sectCu, cal, self.f0, 20.5, 0.623, 18.6, 0.646)
                                self.section.SetLabel(u'%s mm'%result[0])
                                self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                            # si alu
                            if self.ame == "alu" :
                                result = calcSect(sectAlu, cal, self.f0, 16.0, 0.625, 13.4, 0.649)
                                self.section.SetLabel(u'%s mm'%result[0])
                                self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                    # si triphas :
                    else :
                        # si PVC (forcmnt cuivre)
                        if self.isolant == "PVC" :
                            result = calcSect(sectCu, cal, self.f0, 14.3, 0.620, 12.9, 0.640)
                            self.section.SetLabel(u'%s mm'%result[0])
                            self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                            
                        # si PR
                        else :
                            # si cuivre
                            if self.ame == "cuivre" :
                                result = calcSect(sectCu, cal, self.f0, 17.8, 0.623, 16.4, 0.637)
                                self.section.SetLabel(u'%s mm'%result[0])
                                self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                            # si alu
                            if self.ame == "alu" :
                                result = calcSect(sectAlu, cal, self.f0, 13.7, 0.623, 12.6, 0.635)
                                self.section.SetLabel(u'%s mm'%result[0])
                                self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                
                # si mthode F --------------------------------------------------------
                if self.methode == "F":
                    # si monophas
                    if phase == 0 :
                        # si PVC 
                        if self.isolant == "PVC" :
                            # forcment cuivre
                                result = calcSect(sectCu, cal, self.f0, 17.86, 0.623, 16.4, 0.637)
                                self.section.SetLabel(u'%s mm'%result[0])
                                self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                                
                        # si PR
                        else :
                            # si cuivre
                            if self.ame == "cuivre" :
                                result = calcSect(sectCu, cal, self.f0, 20.8, 0.636, 20.8, 0.636)
                                self.section.SetLabel(u'%s mm'%result[0])
                                self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                            # si alu
                            if self.ame == "alu" :
                                result = calcSect(sectAlu, cal, self.f0, 14.7, 0.654, 14.7, 0.654)
                                self.section.SetLabel(u'%s mm'%result[0])
                                self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                    # si triphas :
                    else :
                        # si PVC (forcmnt cuivre)
                        if self.isolant == "PVC" :
                            result = calcSect(sectCu, cal, self.f0, 15.0, 0.625, 15.0, 0.625)
                            self.section.SetLabel(u'%s mm'%result[0])
                            self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                            
                        # si PR
                        else :
                            # si cuivre
                            if self.ame == "cuivre" :
                                result = calcSect(sectCu, cal, self.f0, 18.77, 0.628, 17.0, 0.650)
                                self.section.SetLabel(u'%s mm'%result[0])
                                self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])
                            # si alu
                            if self.ame == "alu" :
                                result = calcSect(sectAlu, cal, self.f0, 14.8, 0.625, 12.6, 0.648)
                                self.section.SetLabel(u'%s mm'%result[0])
                                self.Imax.SetLabel(u'Intensit admissible maximale : %s A'%result[1])

            
                    
                        
            
                

        #------------------------- Appui sur le bouton "BACK" ---------------------------
        else:
            pass
            
            
            
    def onQuitter(self, evt):
        """Quitter l'application"""
        self.parent.btnSection.Enable(True)
        self.parent.menuModuleSection.Enable(True)
        self.Destroy()

